@@ -230,6 +230,21 @@ class HelperFunctions():
             lng=shply_geom.x, lat=shply_geom.y)  # pylint: disable=maybe-no-member
         return coordinates
 
+    @staticmethod
+    def extract_hashtags_from_string(
+        text_str: str) -> List[str]:
+        """Extract hashtags with leading hash-character (#) from string
+
+        - removes # from hashtags
+        - removes duplicates
+        - removes special chars (emoji etc.) from hashtags, e.g.:
+            - input: "#germany🇩🇪"
+            - output: [germany]
+        """
+        hashtag_pattern = re.compile('(?i)(?<=\#)\w+')
+        hashtag_list = hashtag_pattern.findall(text_str)
+        return set(hashtag_list)
+
     @staticmethod
     def json_read_wrapper(gen):
         """Wraps json iterator and catches any error"""
@@ -621,13 +636,10 @@ class HelperFunctions():
         if text is None:
             # keep Null geometries, e.g. for geom_area columns
             return None
-        try:
-            geom = wkt.loads(text)
-            # Set SRID to WGS1984
-            geos.lgeos.GEOSSetSRID(geom._geom, 4326)
-            geom = geom.wkb_hex
-        except:
-            return None
+        geom = wkt.loads(text)
+        # Set SRID to WGS1984
+        geos.lgeos.GEOSSetSRID(geom._geom, 4326)
+        geom = geom.wkb_hex
         return geom
 
     @staticmethod
@@ -768,9 +780,9 @@ class HelperFunctions():
     def check_notice_empty_post_guid(post_guid):
         """Check if post_guid empty and if, raise warning"""
         if not post_guid:
-            logging.getLogger('__main__').warning(f'No PostGuid\n\n'
-                                                  f'{post_guid}')
-            # input("Press Enter to continue... (entry will be skipped)")
+            logging.getLogger('__main__').warning(
+                f'No PostGuid\n\n'
+                f'{post_guid}')
             return False
         return True
 
